import {FC, useState} from "react";
import {View, Text} from "@tarojs/components";
import styles from './index.module.scss'
import {VideoList} from "@/pages/index/components/videoList";
import Tabs, {OnChangOpt, TabList} from "@/components/tabs/tabs";
import {CoursesKey} from "@/api/public";
import LoginView from "@/components/loginView";
import Taro from "@tarojs/taro";
import {Profile} from "@/store"

const Index: FC = () => {
  const globalData = Taro.getApp().globalData
  const {token} = Profile.useContainer()
  const category: TabList[] = [
    {title: "必修", value: 'is_required'},
    {title: "选修", value: 'is_not_required'},
    {title: "已完成", value: 'is_finished'},
    {title: "未完成", value: 'is_not_finished'},
  ]
  const [categoryKey, setCategoryKey] = useState<CoursesKey>('is_required')

  function tabChange(data: OnChangOpt) {
    setCategoryKey(data.tab?.value as CoursesKey)
  }


  return (
      <View className={styles.content} style={`paddingTop:${globalData.statusBarHeight}px`}>
        { !token ?
          <LoginView></LoginView>
          :
          <>
            <View className="flex justify-center align-center" style={{height:`${(globalData.menu.top-globalData.statusBarHeight)*2+globalData.menu.height}px`}}>
              <Text className="font-28 text-white">学习课程</Text>
            </View>
            <Tabs tabList={category} onChange={tabChange} current={categoryKey}/>
            <VideoList categoryKey={categoryKey} setCategoryKey={(categoryKey) => setCategoryKey(categoryKey)}/>
          </>
        }
      </View>
  )
}

export default Index
